# AncillaryInfoResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ancillary_info_reference_number** | **str** |  | 
**location_description** | **str** |  | [optional] 
**ancillary_info_type** | [**AncillaryInfoTypeResponse**](AncillaryInfoTypeResponse.md) |  | 
**ancillary_info_status** | [**AncillaryInfoStatusResponse**](AncillaryInfoStatusResponse.md) |  | 
**ancillary_info_type_string** | **str** |  | 
**ancillary_info_status_string** | **str** |  | 
**date_created** | **datetime** |  | 
**date_removed** | **datetime** |  | [optional] 
**ancillary_info_description** | **str** |  | 
**ancillary_info_removal_reason** | **str** |  | [optional] 
**ancillary_info_coordinates** | **list[object]** |  | 
**usrns** | **list[float]** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

